@@ -80,11 +80,11 @@ export class HVJSExec extends Widget implements IRenderMime.IRenderer {
   private _js_mimetype: string = JS_MIME_TYPE;
   // the metadata is stored here
   private _dispose: boolean;
-  private _document_id: string;
-  private _server_id: string;
+  private _document_id: string | null;
+  private _server_id: string | null;
   private _exec_mimetype: string = HV_EXEC_MIME_TYPE;
-  private _script_element: HTMLScriptElement;
-  private _div_element: HTMLDivElement;
+  private _script_element!: HTMLScriptElement;
+  private _div_element!: HTMLDivElement;
   private _manager: ContextManager;
   private _displayed: boolean;
 
@@ -94,6 +94,8 @@ export class HVJSExec extends Widget implements IRenderMime.IRenderer {
     this._manager = manager;
     this._displayed = false;
     this._dispose = true;
+    this._document_id = null;
+    this._server_id = null;
   }
 
   _createNodes(): void {
@@ -141,9 +143,9 @@ export class HVJSExec extends Widget implements IRenderMime.IRenderer {
           targetName
         );
         return {
-          open: function(): void {},
-          send: function(): void {},
-          onMsg: function(): void {}
+          open: function (): void {},
+          send: function (): void {},
+          onMsg: function (): void {}
         };
       }
       const comm: Kernel.IComm = kernel.createComm(targetName, commId);
@@ -234,7 +236,7 @@ export class HVJSExec extends Widget implements IRenderMime.IRenderer {
         }
         attrs.forEach(attr => newScript.setAttribute(attr.name, attr.value));
         newScript.appendChild(document.createTextNode(oldScript.innerHTML));
-        oldScript.parentNode.replaceChild(newScript, oldScript);
+        oldScript.parentNode?.replaceChild(newScript, oldScript);
       });
       this.node.appendChild(this._div_element);
 
@@ -283,7 +285,7 @@ export class HVJSExec extends Widget implements IRenderMime.IRenderer {
 
   _disposePlot(): void {
     if (this._server_id) {
-      if (this._manager.comm != null && this._dispose) {
+      if (this._manager.comm !== null && this._dispose) {
         this._manager.comm.send({
           event_type: 'server_delete',
           id: this._server_id
@@ -322,8 +324,7 @@ export class HVJSExec extends Widget implements IRenderMime.IRenderer {
     if (this.isDisposed) {
       return;
     }
-    super.dispose();
     this._disposePlot();
-    this._manager = null;
+    super.dispose();
   }
 }
